import { memberType } from '@/constant'
import request from '@/helpers/request'
import { orderStatus } from '@/views/order-detail/orderStatus'
import dayjs from 'dayjs'
// LIVE: '直播课',
// PRACTICE: '陪练课',
// VIDEO: '视频课',
// VIP: '开通会员',
// MUSIC: '单曲点播'
export const formatOrderDetail = async (item: any) => {
  const type = item.goodType
  let tempList: any = {}

  switch (type) {
    case 'LIVE':
      {
        try {
          const live = await getLiveDetail(item.bizId)
          const courseInfo: any[] = []
          const coursePlanList = live.planList || []
          coursePlanList.forEach((item: any) => {
            const startTime = item.startTime || new Date()
            const endTime = item.endTime || new Date()
            courseInfo.push({
              courseTime: `${dayjs(startTime).format('YYYY-MM-DD')} ${dayjs(
                startTime
              ).format('HH:mm')}~${dayjs(endTime).format('HH:mm')}`,
              coursePlan: item.plan,
              id: item.courseId
            })
          })
          tempList = {
            orderType: item.goodType,
            goodName: item.goodName,
            courseGroupId: live.courseGroupId,
            courseGroupName: live.courseGroupName,
            coursePrice: live.coursePrice,
            teacherName: live.teacherName || `游客${live.teacherId || ''}`,
            teacherId: live.teacherId,
            avatar: live.avatar,
            courseInfo
          }
        } catch (e: any) {
          throw new Error(e.message)
        }
      }
      break
    case 'PRACTICE': {
      const bizContent: any = JSON.parse(item.bizContent)
      tempList = {
        ...bizContent,
        teacherName: item.username,
        starGrade: item.starGrade,
        avatar: item.avatar
      }
      break
    }
    case 'VIDEO': {
      try {
        const res = await getVideoDetail(item.bizId)
        const { lessonGroup, detailList } = res
        tempList = {
          orderType: item.goodType,
          goodName: item.goodName,
          courseGroupId: lessonGroup.id,
          courseGroupName: lessonGroup.lessonName,
          coursePrice: lessonGroup.lessonPrice,
          teacherName: lessonGroup.username,
          teacherId: lessonGroup.teacherId,
          avatar: lessonGroup.avatar,
          courseInfo: detailList
        }
      } catch (e: any) {
        throw new Error(e.message)
      }
      break
    }
    case 'VIP':
      {
        try {
          const res = await getVipDetail(item.id)
          tempList = {
            orderType: item.goodType,
            goodName: item.goodName,
            id: res.id,
            title: memberType[res.period] || '',
            price: res.salePrice,
            startTime: dayjs(res.startTime).format('YYYY-MM-DD'),
            endTime: dayjs(res.endTime).format('YYYY-MM-DD')
          }
        } catch (e: any) {
          throw new Error(e.message)
        }
      }
      break
    case 'MUSIC':
      {
        try {
          const res = await getMusicDetail(item.bizId)
          tempList = {
            orderType: item.goodType,
            goodName: item.goodName,
            ...res
          }
        } catch (e: any) {
          throw new Error(e.message)
        }
      }
      break
  }
  tempList.orderType = type
  tempList.goodName = item.goodName
  orderStatus.orderObject.orderList.push(tempList)
}
// 获取视频课详情
export const getVideoDetail = async (groupId: any) => {
  try {
    const res = await request.get(
      '/api-student/videoLesson/selectVideoLesson',
      {
        params: {
          groupId
        }
      }
    )
    return res.data
  } catch {
    throw new Error('获取视频课详情失败')
  }
}

// 获取直播课详情
export const getLiveDetail = async (groupId: any) => {
  try {
    const res = await request.get(
      '/api-student/courseGroup/queryLiveCourseInfo',
      {
        params: {
          groupId
        }
      }
    )
    return res.data
  } catch {
    throw new Error('获取直播课详情失败')
  }
}

// 获取会员详情
export const getVipDetail = async (id: any) => {
  try {
    const setting = await request.get('/api-student/vipCardRecord/detail/' + id)
    return setting.data || []
  } catch {
    throw new Error('获取会员详情失败')
  }
}

// 获取曲目详情
export const getMusicDetail = async (id: any) => {
  try {
    const res = await request.get(`/api-student/music/sheet/detail/${id}`)
    return res.data
  } catch {
    throw new Error('获取曲目详情失败')
  }
}

export const tradeOrder = (result: any, callBack?: any) => {
  const {
    orderNo,
    actualPrice,
    orderDesc,
    orderName,
    orderType,
    orderDetailList
  } = result
  orderStatus.orderObject.orderType = orderType
  orderStatus.orderObject.orderName = orderName
  orderStatus.orderObject.orderDesc = orderDesc
  orderStatus.orderObject.actualPrice = actualPrice
  orderStatus.orderObject.orderNo = orderNo
  orderStatus.orderObject.actualPrice = actualPrice
  orderStatus.orderObject.orderList = []
  try {
    orderDetailList.forEach(async (item: any) => {
      await formatOrderDetail(item)
    })
    callBack && callBack()
  } catch {
    //
  }
}
