import { Button } from 'vant'
import { computed, defineComponent, PropType } from 'vue'
import { IStudent } from '../select-students'
import styles from './index.module.less'

export default defineComponent({
  name: 'CourseSchedule',
  props: {
    item: {
      type: Object,
      default: {}
    },
    students: {
      type: Array as PropType<IStudent[]>,
      default: []
    },
    curriculum: {
      type: Array as PropType<string[]>,
      default: []
    },
    onClose: {
      type: Function,
      default: () => {}
    },
    onComfirm: {
      type: Function,
      default: () => {}
    }
  },
  setup(props) {
    const students = computed(() => {
      let list = props.students.map((n: IStudent) => n.realName)
      return list.join('、')
    })
    return () => (
      <div class={styles.box}>
        <div class={styles.title}>
          <div class={styles.leftIcon}></div>
          课程预览
        </div>
        <div class={styles.wrap}>
          <div class={styles.stu}>
            <div>
              您将为学员：
              <span style={{ color: 'var(--van-primary)' }}>{students.value}</span>
            </div>
            <div>
              排
              <span style={{ color: '#FF4E19', margin: '0 10px' }}>
                {props.item.classNum}节 {props.item.singleClssTime}分钟
              </span>
              课程
            </div>
          </div>
          <div class={styles.timeBox}>
            <div class={styles.timeTitle}>上课时间：</div>
            {props.curriculum.map((item: string) => (
              <div class={styles.timeItem}>{item}</div>
            ))}
          </div>

          <div style={{ color: '#999999' }}>
            以上课程预计将消耗琴房时长{' '}
            {Math.ceil(props.students.length * props.item.classNum * props.item.singleClssTime)} 分钟{' '}
            <br />
            确认排课后时长冻结 <br />
            实际消耗时长以扣减结果为准 <br />
          </div>
        </div>

        <div class={styles.footer}>
          <Button block round onClick={() => props.onClose()}>
            重新选择
          </Button>
          <Button block round type="primary" onClick={() => props.onComfirm()}>
            确认排课
          </Button>
        </div>
      </div>
    )
  }
})
