import { moneyFormat } from '@/helpers/utils'
import {
  Button,
  Cell,
  Dialog,
  Image,
  Loading,
  Radio,
  RadioGroup,
  Stepper,
  Tag,
  Toast
} from 'vant'
import { defineComponent } from 'vue'
import styles from './index.module.less'
import iconSellOut from '../../images/icon-sell-out.png'
import request from '@/helpers/request'

export default defineComponent({
  name: 'add-goods-cart',
  props: {
    item: {
      type: Object,
      default: {}
    },
    defaultRadio: {
      type: Number,
      default: 0
    },
    onOpenWebView: {
      type: Function,
      default: (n: any) => {}
    }
  },
  data() {
    return {
      radio: '',
      selectItem: {
        id: '',
        pic: '',
        stock: 0,
        price: 0,
        spDataJson: '',
        skuCode: ''
      },
      total: 1
    }
  },
  computed: {
    skuStockList() {
      // 处理规格
      const skuStockList = this.item.skuStockList || [
        {
          id: -1,
          price: this.item.price,
          pic: this.item.pic,
          stock: this.item.stock,
          spData: null
        }
      ]
      skuStockList.forEach((item: any) => {
        if (item.spData) {
          const spData = JSON.parse(item.spData)
          let str = ''
          spData.forEach((sp: any) => {
            str += `${sp.value}`
          })
          item.spDataJson = str
        } else {
          item.spDataJson = '默认'
        }
      })
      // 处理默认显示
      let index = 0
      if (this.defaultRadio) {
        let i = skuStockList.findIndex(n => n.id == this.defaultRadio)
        index = i > -1 ? i : 0
      }
      const { id, price, pic, stock, spDataJson, skuCode } = skuStockList[index]
      this.radio = id
      this.selectItem = {
        id,
        price,
        pic: pic || this.item.pic,
        stock,
        spDataJson,
        skuCode
      }

      return skuStockList
    }
  },
  mounted() {},
  methods: {
    async onAddCart() {
      // console.log(this.total, this.selectItem, this.item)
      const selectItem = this.selectItem
      const item = this.item
      const body = {
        price: selectItem.price, //添加到购物车的价格
        productSkuId: selectItem.id,
        quantity: this.total, // 数量
        productId: item.id
      }
      // console.log(body)
      try {
        let { code, data } = await request.post('/api-mall-portal/cart/add', {
          data: body
        })
        if (code === 200) {
          Dialog.confirm({
            title: '提示',
            message: '加入购物车成功,是否去决算?',
            cancelButtonText: '继续购买',
            confirmButtonText: '去结算',
            confirmButtonColor: 'var(--van-primary)'
          })
            .then(() => {
              // 如果为首页加入购物车跳转, 使用首页的公用跳转方法
              if (this.onOpenWebView.toString() === 'n => {}') {
                this.$router.push({
                  path: '/cart'
                })
              } else {
                this.onOpenWebView('/cart')
              }
              // on confirm
            })
            .catch(() => {
              // on cancel
            })
        }
      } catch (error) {}
    }
  },
  render() {
    const item = this.item
    return (
      <div class={styles.addGoodsCart}>
        <Cell
          titleStyle={{ paddingLeft: '12px' }}
          v-slots={{
            icon: () => (
              <div class={styles.goodsSection}>
                <Image
                  src={this.selectItem.pic}
                  class={styles.goodsImg}
                  fit="cover"
                />
                {this.selectItem.stock <= 0 && (
                  <div class={styles.sellOut}>
                    <Image
                      src={iconSellOut}
                      fit="cover"
                      class={styles.sellOutImg}
                    />
                  </div>
                )}
              </div>
            ),
            title: () => (
              <div class={styles.goodsInfo}>
                <p class={styles.goodsPrice}>
                  <span>￥</span>
                  {moneyFormat(this.selectItem.price)}
                </p>
                <p class={styles.goodsStore}>库存：{this.selectItem.stock}</p>
              </div>
            )
          }}
        />
        <Cell
          v-slots={{
            title: () => <div class={styles.title}>规格</div>,
            label: () => (
              <RadioGroup
                class={styles['radio-group']}
                modelValue={this.radio}
                onUpdate:modelValue={val => (this.radio = val)}
              >
                {this.skuStockList.map((item: any) => {
                  const isActive = item.id === this.radio
                  const type = isActive ? 'primary' : 'default'
                  return (
                    <Radio
                      class={styles.radio}
                      name={item.id}
                      onClick={() => {
                        this.radio = item.id
                        // 处理默认显示
                        const { id, price, pic, stock, spDataJson, skuCode } =
                          item
                        this.radio = id
                        this.selectItem = {
                          id,
                          price,
                          pic: pic || this.item.pic,
                          stock,
                          spDataJson,
                          skuCode
                        }
                      }}
                    >
                      <Tag size="large" plain={isActive} type={type}>
                        {item.spDataJson}
                      </Tag>
                    </Radio>
                  )
                })}
              </RadioGroup>
            )
          }}
        />
        <Cell
          title="购买数量"
          style={{ margin: '12px 0' }}
          border={false}
          titleClass={styles.title}
          center
        >
          <Stepper
            v-model={this.total}
            inputWidth="50px"
            theme="round"
            buttonSize="24px"
            max={this.selectItem.stock}
            min={1}
            disabled={this.selectItem.stock <= 0}
          />
        </Cell>
        <div class={['btnGroup']} style={{ marginBottom: '8px' }}>
          <Button
            block
            round
            type="primary"
            text="确定"
            disabled={this.selectItem.stock <= 0}
            onClick={() => this.onAddCart()}
          />
        </div>
      </div>
    )
  }
})
