import request from '@/helpers/request'
import { Divider, Cell, CellGroup } from 'vant'
import { computed, defineComponent, onMounted, reactive, ref } from 'vue'
import { useRoute } from 'vue-router'
import ShopItem from '../components/shop-item'
import styles from './index.module.less'
import { orderState } from '@/views/shop-mall/shop-mall'
import { moneyFormat } from '@/helpers/utils'

export default defineComponent({
  name: 'shop-order-detail',
  setup() {
    const route = useRoute()
    let items = ref([])
    let order = ref({}) as any
    const getOrderInfo = async () => {
      const id = route.query.id
      if (!id) return
      try {
        let { code, data } = await request.get(
          `/api-mall-portal/order/detail/${id}`
        )
        if (code === 200) {
          items.value = data.orderItemList
          delete data.orderItemList
          order.value = data
          order.value.address_data = [
            data.receiverProvince,
            data.receiverCity,
            data.receiverRegion,
            data.receiverDetailAddress
          ].join('')
        }
      } catch (error) {}
    }
    onMounted(() => {
      getOrderInfo()
    })

    return () => (
      <>
        {items.value.length ? (
          <div class={styles.shopOrderDetail}>
            <div class={styles.box}>
              {items.value.map((item: any, index: number) => (
                <div>
                  <ShopItem item={item}></ShopItem>
                  {index === items.value.length - 1 ? null : (
                    <Divider></Divider>
                  )}
                </div>
              ))}
            </div>

            <div class={styles.box} style={{ padding: 0 }}>
              <Cell
                border={false}
                title="商品价格："
                value={'¥ ' + moneyFormat(order.value?.totalAmount)}
              ></Cell>
              <Cell
                border={false}
                title="优惠价格："
                value={'-¥ ' + moneyFormat(order.value?.promotionAmount)}
              ></Cell>
              <Cell
                border={false}
                title="订单状态："
                value={orderState[order.value?.status]}
              ></Cell>
              <Cell
                border={false}
                title="收货状态："
                value={order.value?.confirmStatus ? '已确认收货' : '未确认收货'}
              ></Cell>
              <Divider style={{ margin: 0 }}></Divider>
              <Cell
                border={false}
                title="订单号："
                value={order.value?.orderSn}
              ></Cell>

              <Cell
                border={false}
                title="创建时间："
                value={order.value?.createTime}
              ></Cell>
              <Cell
                border={false}
                title="付款时间："
                value={order.value?.paymentTime}
              ></Cell>
            </div>

            <div class={styles.box} style={{ padding: 0 }}>
              <CellGroup title="收货信息" border={false}>
                <Cell
                  border={false}
                  title="姓名："
                  value={order.value?.receiverName}
                ></Cell>
                <Cell
                  border={false}
                  title="手机号："
                  value={order.value?.receiverPhone}
                ></Cell>
                <Cell
                  class={styles.addressDetail}
                  border={false}
                  title="地址："
                  value={order.value?.address_data}
                ></Cell>
                <Cell
                  class={styles.addressDetail}
                  border={false}
                  title="物流公司(配送方式):"
                  value={order.value?.deliveryCompany}
                ></Cell>
                <Cell
                  border={false}
                  title="运单编号："
                  value={order.value?.deliverySn}
                ></Cell>
              </CellGroup>
            </div>
          </div>
        ) : null}
      </>
    )
  }
})
